#
# spec file for package pasystray
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pasystray
Version:        0.8.2
Release:        1.6
Summary:        PulseAudio system tray
License:        LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://github.com/christophgysin/pasystray
Source:         https://github.com/christophgysin/pasystray/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(avahi-ui-gtk3)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-broadway-3.0)
BuildRequires:  pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-broadway-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-wayland-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libpulse-simple)
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
Suggests:       paman
Suggests:       paprefs
Suggests:       pavucontrol
Suggests:       pavumeter

%description
A replacement for the deprecated padevchooser

Pasystray allows setting the default PulseAudio source/sink and moving streams on the fly between sources/sinks without restarting the client applications.

%prep
%setup -q

%build
autoreconf -fi
%configure --sysconfdir=%{_sysconfdir}
%make_build

%install
%make_install
%suse_update_desktop_file  -u -r %{buildroot}%{_datadir}/applications/pasystray.desktop AudioVideo Mixer
%suse_update_desktop_file  -u -r %{buildroot}%{_sysconfdir}/xdg/autostart/pasystray.desktop AudioVideo Mixer

%files
%license LICENSE
%doc AUTHORS README.md TODO
%dir %{_datadir}/pasystray
%{_sysconfdir}/xdg/autostart/pasystray.desktop
%{_bindir}/pasystray
%{_datadir}/applications/pasystray.desktop
%{_datadir}/icons/hicolor/scalable/apps/pasystray.svg
%{_mandir}/man1/pasystray.1%{?ext_man}
%{_datadir}/pasystray/pasystray.gtk3.glade
%{_datadir}/pixmaps/pasystray.png

%changelog
* Sun Feb 19 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.2:
  * Fix spurious "item activated: input (null)"
  * Improve logging in pulseaudio_action.c
  * Fix defaults being changed and streams moved without user
    interaction
  * Fix alt-click/right-click setting defaults in addition to
    muting
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * Explicit opt-in for symbolic icons
  * documentation updates
* Tue May  3 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.0
  * volume: calculate notify value to always be between 0-100
    fixes volume-max not working
  * Fix null unref in pulseaudio_terminate
  * Prefer symbolic icons, use microphone sensitivity icons.
  * Import X11 volume control key grabber from pa-applet and
    use for volume control
  * Use volume max for icon instead of avg
  * Listen to activate events of menu items
    The new `activate` handlers substitute the current click
    handlers for default left click events
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Keep Requires: pulseaudio when building on SLE/Leap before 15.3.
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Tue Oct  8 2019 Petr Cervinka <petr@cervinka.net>
- Drop dependency on avahi-ui
* Fri Feb 15 2019 Petr Cervinka <petr@cervinka.net>
- Disable appindicator support (boo#1125586)
* Sat Jan  5 2019 Petr Cervinka <petr@cervinka.net>
- Version bump to 0.7.1:
  * Check stream_input and stream_output settings
* Mon Oct  1 2018 Petr Cervinka <petr@cervinka.net>
- Fix build on Leap 42.3
* Mon Oct  1 2018 Petr Cervinka <petr@cervinka.net>
- Version bump to 0.7.0:
  * Disable status icon tooltip for connected state
  * Fix: Recognize the option -N systray_action
  * systray: fix memory leak
  * Add option to terminate server
  * Split glade for gtk2/3
  * Fix coding style
  * Deprecate old notification options
  * Remove deprecated option max-volume
  * Simplify notification handling
  * Granular notification options
  * Set fallback icon for notifications where no icon is provided
  * Capitalization in new sink/source notification
  * Update item on failed move
  * Fix segfault on failed move
  * Fix capitalization of stream menu items
  * autotools: split EXTRA_DIST, add man page and desktop entry
  * Make glade gtk2 compatible
- Remove fix-memory-leak.patch, fixed in upstream
* Tue Apr 10 2018 mpluskal@suse.com
- Update dependencies
* Tue Apr 10 2018 petr@cervinka.net
- Add pulseaudio as dependency (boo#1084813)
- Apply spec-cleaner
* Tue Nov 28 2017 petr@cervinka.net
- Add upstream patch fix-memory-leak.patch for memory leak (boo#1070195)
- spec file cleaned
* Mon Jul 18 2016 petr@cervinka.net
- Version bump to 0.6.0:
  * start pavucontrol with ctrl-click on status icon
  * update systray icon on default sink change
  * add context menu option to move all in/outputs to sink/source
  * update the volume icon of non-default sinks
  * To fix notifications for changes of their volume level
  * possible to set the volume icon for notifications independent of the tray icon
  * use gauges for volume notifications
  * set notification icon when changing systray icon
  * send notifications only on volume / mute changes
  * add option to always send notifications on volume change
  * log systray implementation
  * add option to include monitors
  * support disabling status icon support
  * include volume and muted state in item name
  * set notification urgency to low
  * minor Housekeeping for README
  * deprecate --max-volume in favor of --volume-max
  * add option to disable all notifications
  * re-add volume-max option handling
  * update manpage with --volume-inc
  * add option to set volume increment
  * add TODO entries for feature requests
  * stop using stock GtkButton
  * check mii only where needed
  * start pavucontrol with ctrl-click on status icon
  * pasystray.desktop: Add missing semicolon to "Keywords"
- Removed patch icon_keywords_fix.patch (fixed in upstream)
* Mon Jan 11 2016 petr@cervinka.net
- updated License to LGPL-2.1+ in spec file
* Thu Jan  7 2016 petr.cervinka@gmail.com
- New package
- pasystray.desktop: Add missing semicolon to "Keywords"
- disabled wayland in build requirements for Leap 42.1 / SLE12
- spec file cleaned
